@@ -293,9 +293,9 @@ treeToHtml2 ll
           = return ("&"++s++";")
         nodeToHtml (Environment Wikilink _ l)
           = do st <- get
-               if getInHeading st then return $ wikiLinkCaption l st else
+               if getInHeading st then return $ wikiLinkCaptionHtml l st else
                  if (isImage (shallowFlatten l)) then wikiImageToHtml l else
-                   return $ wikiLinkCaption l st
+                   return $ wikiLinkCaptionHtml l st
         nodeToHtml (Environment Tag (TagAttr "br" _) _) = return "<br/>"
         nodeToHtml (Environment Tag (TagAttr "script" _) _) = return []
         nodeToHtml (Environment Source (TagAttr _ _) l)
