@@ -155,7 +155,7 @@ runqBookIncludeAction dir
 
 qBookIncludeActionbase :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
 qBookIncludeActionbase cfg wurl text 
-  =  if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return ""
+  =  if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if (isInfixOf "Category:" text) || (isInfixOf "Kategorie:" text) then return ""
                    else
                      do pp <- (liftIO (print d)) >> myfun
                         case pp of
@@ -186,7 +186,7 @@ qBookIncludeAction :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
 qBookIncludeAction cfg wurl text 
   = do sst <- get
        case (loadacu sst) of
-        Right _ ->   if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return "" else if (noparent cfg) && case text of {'/':_->False; _->True} &&(fromMaybe False (wurl >>= (return.not.((flip Data.List.isPrefixOf) text).(intercalate "/").(Data.List.dropWhile (=="wiki")).(splitOn "/").url_path.fst))) then return "" else
+        Right _ ->   if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if (isInfixOf "Category:" text) || (isInfixOf "Kategorie:" text) then return "" else if (noparent cfg) && case text of {'/':_->False; _->True} &&(fromMaybe False (wurl >>= (return.not.((flip Data.List.isPrefixOf) text).(intercalate "/").(Data.List.dropWhile (=="wiki")).(splitOn "/").url_path.fst))) then return "" else
                         do pp <- (liftIO (print d)) >> myfun
                            case pp of
                             Just p -> do _ <- addContributors d Nothing
@@ -202,7 +202,7 @@ qBookIncludeAction cfg wurl text
                                           Left base -> put st{loadacu = Left (tempdir: base)}
                                          return x
                             _ -> return  ""
-        Left _ -> if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return "" else if (noparent cfg)&& case text of {'/':_->False; _->True} && (fromMaybe False (wurl >>= (return.not.((flip Data.List.isPrefixOf) text).(intercalate "/").(Data.List.dropWhile (=="wiki")).(splitOn "/").url_path.fst))) then return "" else
+        Left _ -> if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if (isInfixOf "Category:" text) || (isInfixOf "Kategorie:" text) then return "" else if (noparent cfg)&& case text of {'/':_->False; _->True} && (fromMaybe False (wurl >>= (return.not.((flip Data.List.isPrefixOf) text).(intercalate "/").(Data.List.dropWhile (=="wiki")).(splitOn "/").url_path.fst))) then return "" else
                      do systempdir <- liftIO getTemporaryDirectory
                         tempdir <- liftIO $  createTempDirectory systempdir "MediaWiki2LaTeXBook"
                         liftIO $ B.writeFile (tempdir </> "bookinput") (S.encode (cfg,wurl,text,loadacu sst,audict sst,fullUrl sst))
