@@ -533,7 +533,7 @@ removePrintVersion lem
 
 goodtags1 :: [[Char]]
 goodtags1
-  = ["includeonly", "references", "blockquote", "noinclude",
+  = ["templatestyles", "includeonly", "references", "blockquote", "noinclude",
      "noframes", "frameset", "colgroup", "fieldset", "basefont",
      "!DOCTYPE", "noscript", "address", "acronym", "caption", "strong",
      "applet", "script", "button", "select", "section", "legend", "footer",
