@@ -103,7 +103,7 @@ simpleContributors theLemma theHost uu st
                                                                                                   mm
                                                                                                 of
                                                                                                   (Just
-                                                                                                     x) -> "https://"
+                                                                                                     x) -> if (Data.List.take 8 x == "https://") then        (replace2 x "&amp;" "&") else "https://"
                                                                                                              ++
                                                                                                              theHost
                                                                                                                ++
@@ -140,6 +140,7 @@ simpleContributors theLemma theHost uu st
         go _ = ("", "")
         go2 (c, (a, h)) = (a, h, c, Nothing)
 
+
 count :: (Eq a) => [a] -> a -> Int
 count l s = length (filter (== s) l)
 
