@@ -259,14 +259,16 @@ getpage ss u
 
 getBookpage :: String -> WikiUrl -> IO (Maybe String)
 getBookpage ss u
-  = do l <- mapM ((geturl2) . unify)  ((map ((++("/"++ss)).exportURL)) (parses u))
+  = do l <- mapM ((geturl2) . unify)  ((map attach) (map exportURL (parses u)))
        lll <- return (seq l l)
        return $
          (listToMaybe $ concat (map maybeToList (map go lll))) >>=
            (return)
   where
     go x =if (x==(UTF8Str.fromString [])) then Nothing else Just (UTF8Str.toString x)
-
+    attach x = case reverse x of
+                 '/':xs -> ((reverse xs)++("/"++ss))
+                 xs-> ((reverse xs)++("/"++ss))
 
 {-DHUN| Loads the wikitext of an article form a mediawiki server when mediawiki2latex is running with the --mediawiki option. This function downloads the orignial wikitext source without expanding the templates. This is going to happen later by call to getExpandedPage. The first parmeter is lemma to load. The second paramerter is the WikiUrl to the server hosting the wiki. The return value is a pair. The first element of it is the wikitext source of the article. The second element of it is the URL under which the article was downloaded DHUN-}
 
