@@ -243,7 +243,8 @@ replist
      ("\\begin{align}", "\\begin{aligned}"),
      ("\\end{align}", "\\end{aligned}"), ("\\\\%", "\\%"),
      ("\\part ", "\\partial "), ("\\part{", "\\partial{"), ("\\;", ""),
-     ("\\|", "\\Vert"), ("\\!", ""), ("\\part\\", "\\partial\\")]
+     ("\\|", "\\Vert"), ("\\!", ""), ("\\part\\", "\\partial\\"),  ("&#10;", "{\\newline}"),
+     ("&#39;", "'")]
 
 {-DHUN| helper function for line breaking in source code and preformatted block. Not to be called from outside this module. Converts character to parse tree entities, to be process by breakLinesHelper3 DHUN-}
 
